﻿using Silanis.ESL.SDK;
using Silanis.ESL.SDK.Builder;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace FeatureGuideCharp
{
    class _10_15
    {

        public void updateSigner()
        {
            String apiKey = "your api key";
            String apiUrl = "https://sandbox.esignlive.com/api";


            //1. create a package
            EslClient eslClient = new EslClient(apiKey, apiUrl);
            string signerId = "Signer";
            string signerEmail = "signer1@mailinator.com";
            string firstname = "signer.firstname";
            string lastname = "signer.lastname";
            string company = "abc bank";
            string title = "CEO";

            DocumentPackage package = PackageBuilder
              .NewPackageNamed("Test update Signer")
                    .WithSigner(
                         signerCreator(signerId, signerEmail, firstname, lastname, company, title)
                                )
                    .WithDocument(DocumentBuilder.NewDocumentNamed("testpdf.pdf")
                                  .FromFile("your file path")
                                  .WithId("testpdf.pdf")
                                  .WithSignature(SignatureBuilder
                                       .SignatureFor(signerEmail)
                                         .OnPage(0)
                                         .AtPosition(200, 300)
                                         .WithField(FieldBuilder.SignatureDate().OnPage(0).AtPosition(200, 400))
                                         )
                    )
                    .Build();
            PackageId packageId = eslClient.CreatePackageOneStep(package);
            eslClient.SendPackage(packageId);
            Debugger.Log(1, "Debug", packageId.ToString() + "\n");

            //2. sent draft first, then grab your signer 
            eslClient.ChangePackageStatusToDraft(packageId);
            Signer signer = eslClient.PackageService.GetSigner(packageId, signerId);

            //3. create a new signer and inject all properties otherwise your properties will get lost
            Signer updatedSigner = signerCreator(signerId, "signer2@mailinator.com", firstname, lastname, company, title);
            eslClient.PackageService.UpdateSigner(packageId, updatedSigner);


            eslClient.SendPackage(packageId);


        }

        private Signer signerCreator(string signerId, string email, string firstname, string lastname, string company, string title) {
            return SignerBuilder.NewSignerWithEmail(email)
                                .WithFirstName(firstname)
                                .WithLastName(lastname)
                                .WithCustomId(signerId)
                                .WithCompany(company)
                                .WithTitle(title)
                                .Build();
        }

    }
}
